@@ -30,16 +30,30 @@ sub create {
 #            $kernel->yield('create_status_session');
             $kernel->yield('create_progress_session');
 
-            my ($screen_w, $screen_h);
-            $class->get_curses_handler()->getmaxyx($screen_h, $screen_w);
-    
+            # the root session is special, it's the only one handling the
+            # window size change signal. It takes care of changing it to events
+            $kernel->sig(WINCH => 'sig_window_resize');
+
             $heap->{'pos_x'} = 0;
-            $heap->{'pos_y'} = $screen_h - 2;
-            $heap->{width} = $screen_w;
             $heap->{height} = 1;
 
-            $kernel->call('root', 'draw');
-
+        },
+        sig_window_resize => sub { 
+            my ($kernel, $heap) = @_[ KERNEL, HEAP];
+            $class->restart_curses();
+			my %sessions = $class->get_sessions();
+			my @sessions_names = keys(%sessions);
+			# send the window_resize to all sessions (including root)
+			foreach my $name (@sessions_names) {
+				# window resize signal provided by default (see Session.pm)
+				$kernel->call($name, '__window_resize');
+			}
+        },
+        window_resize => sub {
+            my ($kernel, $heap, $old_screen_h, $old_screen_w) = @_[ KERNEL, HEAP, ARG0, ARG1 ];
+            $heap->{pos_y} = $heap->{screen_h} - 2;
+            print STDERR " -- ROOT -- window resize " . $heap->{screen_w} . " | " . $heap->{screen_h} . "\n";
+            $heap->{width} = $heap->{screen_w};
         },
         available_keys => sub {
             my @available_list = ();
@@ -61,8 +75,8 @@ sub create {
         draw => sub {
             my ($kernel, $heap) = @_[ KERNEL, HEAP ];
             my @keys = $kernel->call(root => 'available_keys');
-            $class->draw_keys_label( Y => $heap->{'pos_y'},
-                                     X => $heap->{'pos_x'},
+            $class->draw_keys_label( Y => $heap->{pos_y},
+                                     X => $heap->{pos_x},
                                      COLUMNS => $heap->{width},
                                      VALUE => \@keys,
                                    );
