@@ -23,16 +23,13 @@ sub create {
     inline_states => {
         init => sub {
             my ($kernel, $heap) = @_[ KERNEL, HEAP ];
-            print STDERR "ticket_custfields : init\n";
-
-            my ($screen_w, $screen_h);
-            $class->get_curses_handler()->getmaxyx($screen_h, $screen_w);
-
             $heap->{pos_x } = 0;
             $heap->{pos_y } = 1 + 7;  # tabs-bar + headers
-            $heap->{width } = $screen_w * 2 / 3 - 2;  # - border
             $heap->{height} = 4;
-
+        },
+        window_resize => sub { 
+            my ($kernel, $heap, $old_screen_h, $old_screen_w) = @_[ KERNEL, HEAP, ARG0, ARG1 ];
+            $heap->{width} = $heap->{screen_w} * 2 / 3 - 2;  # - border
         },
         available_keys => sub {
             return (['u', 'change custom fields', 'change_custfields']);
